@@ -9,11 +9,16 @@ import shutil
 from . import escapes
 
 
-# Exception class for reporting errors.
+# Deprecated error class.
 class Error(Exception):
     pass
 
 
+# Exception class for reporting errors.
+class SyntextError(Error):
+    pass
+
+
 # Makes input text available as a stream of lines. Strips newlines.
 class LineStream:
 
